Module blaxel.core.client.models.integration
============================================

Classes
-------

`Integration(additional_infos: blaxel.core.client.types.Unset | ForwardRef('IntegrationAdditionalInfos') = <blaxel.core.client.types.Unset object>, endpoints: blaxel.core.client.types.Unset | ForwardRef('IntegrationEndpoints') = <blaxel.core.client.types.Unset object>, headers: blaxel.core.client.types.Unset | ForwardRef('IntegrationHeaders') = <blaxel.core.client.types.Unset object>, name: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, organizations: blaxel.core.client.types.Unset | list['IntegrationOrganization'] = <blaxel.core.client.types.Unset object>, params: blaxel.core.client.types.Unset | ForwardRef('IntegrationQueryParams') = <blaxel.core.client.types.Unset object>, repositories: blaxel.core.client.types.Unset | list['IntegrationRepository'] = <blaxel.core.client.types.Unset object>)`
:   Integration
    
    Attributes:
        additional_infos (Union[Unset, IntegrationAdditionalInfos]): Integration additional infos
        endpoints (Union[Unset, IntegrationEndpoints]): Integration endpoints
        headers (Union[Unset, IntegrationHeaders]): Integration headers
        name (Union[Unset, str]): Integration name
        organizations (Union[Unset, list['IntegrationOrganization']]): Integration organizations
        params (Union[Unset, IntegrationQueryParams]): Integration query params
        repositories (Union[Unset, list['IntegrationRepository']]): Integration repositories
    
    Method generated by attrs for class Integration.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_infos`
    :

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `endpoints`
    :

    `headers`
    :

    `name`
    :

    `organizations`
    :

    `params`
    :

    `repositories`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :